@@ -1,5 +1,5 @@
 logitGL <-
-function(y, X, index, lam.path = NULL, thresh = 10^(-4), maxit = 100, nlam = 100, min.lam.frac = 0.05, is.pen = rep(1,length(index))){
+function(y, X, index, lam.path = NULL, thresh = 10^(-4), maxit = 100, nlam = 100, min.lam.frac = 0.05, is.pen = rep(1,length(unique(index)))){
 
   numGroups <- length(unique(index))
   groupLen <- rep(0,numGroups)
@@ -24,8 +24,8 @@ function(y, X, index, lam.path = NULL, thresh = 10^(-4), maxit = 100, nlam = 100
     lam.path <- logitcalcLam(y, Us, index, nlam, min.lam.frac)
   }
 
-  oldFit <- matrix(0, ncol = length(index), nrow = length(y))
-  resid <- y
+  oldFit <- matrix(0, ncol = length(unique(index)), nrow = length(y))
+  resid <- y - 0.5
 
   Betas <- matrix(0, ncol = length(lam.path), nrow = ncol(X))
   
